# wehoop-py <a href='http://github.com/saiemgilani/wehoop-py'><img src='wehoop-py-logo.png' align="right" height="150" /></a>
<!-- badges: start -->
![Lifecycle:experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg?style=for-the-badge&logo=github)
[![PyPI](https://img.shields.io/pypi/v/wehoop-py?label=wehoop-py&logo=python&style=for-the-badge)](https://pypi.org/project/wehoop-py/)
![Contributors](https://img.shields.io/github/contributors/saiemgilani/wehoop-py?style=for-the-badge)
[![Twitter
Follow](https://img.shields.io/twitter/follow/saiemgilani?color=blue&label=%40saiemgilani&logo=twitter&style=for-the-badge)](https://twitter.com/saiemgilani)
<!-- badges: end -->


See [CHANGELOG.md](http://github.com/saiemgilani/wehoop-py/CHANGELOG.md) for details.

[wehoop-py](https://github.com/saiemgilani/wehoop-py) is an Python package for working with women’s basketball data and companion package to [wehoop](https://github.com/saiemgilani/wehoop)

The package has functions to access live play by play and box score data from ESPN with shot locations when available.

## Installation

wehoop-py can be installed via pip:

```bash
pip install wehoop-py
```

or from the repo (which may at times be more up to date):

```bash
git clone https://github.com/saiemgilani/wehoop-py
cd wehoop-py
pip install -e .
```

# **Our Authors**

-   [Saiem Gilani](https://twitter.com/saiemgilani)       
<a href="https://twitter.com/saiemgilani" target="blank"><img src="https://img.shields.io/twitter/follow/saiemgilani?color=blue&label=%40saiemgilani&logo=twitter&style=for-the-badge" alt="@saiemgilani" /></a>
<a href="https://github.com/saiemgilani" target="blank"><img src="https://img.shields.io/github/followers/saiemgilani?color=eee&logo=Github&style=for-the-badge" alt="@saiemgilani" /></a>


## **Citations**

To cite the [**`wehoop-py`**](https://saiemgilani.github.io/wehoop-py/) Python package in publications, use:

BibTex Citation
```bibtex
@misc{saiemgilani2021wehooppy,
  author = {Gilani, Saiem},
  title = {wehoop-py: The SportsDataverse's Python package for Women's Basketball Data.},
  url = {https://saiemgilani.github.io/wehoop-py/},
  year = {2021}
}
```
